@@ -24,10 +24,12 @@ class Selenium(Scraper):
     def __init__(self, headless: bool=True, window: dict={}, user_dir: str=None):
         options = webdriver.ChromeOptions()
 
+        url = self.config.get(section='SELENIUM', key='url')
+
         options.add_argument('--no-sandbox')
         options.add_argument('--disable-dev-shm-usage')
-        options.add_arguments('--start-maximized')
-        self.driver = webdriver.Remote(command_executor='http://selenium:4443/wd/hub', desired_capabilities={'browserName': 'chrome'}, options=options)
+        options.add_argument('--start-maximized')
+        self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
 
         # #region undetected_chromedriver
         # # setting profile
